@@ -233,8 +233,7 @@ def execute(
                     cache_ctrl()
                 if cacheable and cache_norm():
                     set_status(304)
-                    return
-                if not cache_strat():
+                elif not cacheable or (cacheable and not cache_strat()):
                     method_main()
                     if cacheable:
                         cache_store(__response)
